@@ -44,15 +44,15 @@ class AllowRebalanceTestCase(unittest.TestCase):
             def signals_to_target_weights(self, signals, prices):
                 return self.allocate_fixed_weights(signals, 0.5)
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -61,12 +61,14 @@ class AllowRebalanceTestCase(unittest.TestCase):
                  },
                 index=idx
             )
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
 
             master_fields = ["Timezone", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
                         "STK",
                         "USD",
@@ -74,9 +76,11 @@ class AllowRebalanceTestCase(unittest.TestCase):
                         None
                     ],
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
         def mock_download_account_balances(f, **kwargs):
             balances = pd.DataFrame(dict(Account=["U123", "DU234"],
@@ -97,36 +101,40 @@ class AllowRebalanceTestCase(unittest.TestCase):
                 {
                     "Account": "U123",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 2240
                 },
                 {
                     "Account": "DU234",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 7100
                 },
             ]
             return positions
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
+        def mock_download_order_statuses(f, **kwargs):
+            pass
+
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
             with patch("moonshot.strategies.base.download_account_balances", new=mock_download_account_balances):
                 with patch("moonshot.strategies.base.download_exchange_rates", new=mock_download_exchange_rates):
                     with patch("moonshot.strategies.base.list_positions", new=mock_list_positions):
+                        with patch("moonshot.strategies.base.download_order_statuses", new=mock_download_order_statuses):
+                            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
 
-                        orders = BuyBelow10().trade(
-                            {"U123": 0.5,
-                             "DU234": 0.3,
-                             })
+                                orders = BuyBelow10().trade(
+                                    {"U123": 0.5,
+                                        "DU234": 0.3,
+                                        })
 
         self.assertSetEqual(
             set(orders.columns),
-            {'ConId',
+            {'Sid',
              'Account',
              'Action',
              'OrderRef',
              'TotalQuantity',
-             'Exchange',
              'OrderType',
              'Tif'}
         )
@@ -134,24 +142,22 @@ class AllowRebalanceTestCase(unittest.TestCase):
             orders.to_dict(orient="records"),
             [
                 {
-                    'ConId': 12345,
+                    'Sid': "FI12345",
                     'Account': 'U123',
                     'Action': 'SELL',
                     'OrderRef': 'buy-below-10',
                     # 0.5 allocation * 0.5 weight * 85K / 9.50 - 2240
                     'TotalQuantity': 3,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 },
                 {
-                    'ConId': 12345,
+                    'Sid': "FI12345",
                     'Account': 'DU234',
                     'Action': 'BUY',
                     'OrderRef': 'buy-below-10',
                     # 0.3 allocation * 0.5 weight * 450K / 9.50 - 7100
                     'TotalQuantity': 5,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 }
@@ -179,21 +185,21 @@ class AllowRebalanceTestCase(unittest.TestCase):
             def signals_to_target_weights(self, signals, prices):
                 return self.allocate_fixed_weights(signals, 0.5)
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
                         9.50
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         8.9,
                         12,
@@ -203,18 +209,21 @@ class AllowRebalanceTestCase(unittest.TestCase):
                 index=idx
             )
 
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
             master_fields = ["Timezone", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
                         "STK",
                         "USD",
                         None,
                         None
                     ],
-                    23456: [
+                    "FI23456": [
                         "America/New_York",
                         "STK",
                         "USD",
@@ -222,9 +231,11 @@ class AllowRebalanceTestCase(unittest.TestCase):
                         None
                     ],
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
         def mock_download_account_balances(f, **kwargs):
             balances = pd.DataFrame(dict(Account=["U123", "DU234"],
@@ -246,45 +257,49 @@ class AllowRebalanceTestCase(unittest.TestCase):
                     # this position won't be rebalanced
                     "Account": "U123",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 200
                 },
                 {
                       # this position will switch sides
                       "Account": "DU234",
                       "OrderRef": "buy-below-10",
-                      "ConId": 12345,
+                      "Sid": "FI12345",
                       "Quantity": -4
                 },
                 {
                     # this position will be closed
                     "Account": "DU234",
                     "OrderRef": "buy-below-10",
-                    "ConId": 23456,
+                    "Sid": "FI23456",
                     "Quantity": -7
                 },
 
             ]
             return positions
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
+        def mock_download_order_statuses(f, **kwargs):
+            pass
+
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
             with patch("moonshot.strategies.base.download_account_balances", new=mock_download_account_balances):
                 with patch("moonshot.strategies.base.download_exchange_rates", new=mock_download_exchange_rates):
                     with patch("moonshot.strategies.base.list_positions", new=mock_list_positions):
+                        with patch("moonshot.strategies.base.download_order_statuses", new=mock_download_order_statuses):
+                            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
 
-                        orders = BuyBelow10().trade(
-                            {"U123": 0.5,
-                             "DU234": 0.3,
-                             })
+                                orders = BuyBelow10().trade(
+                                    {"U123": 0.5,
+                                        "DU234": 0.3,
+                                        })
 
         self.assertSetEqual(
             set(orders.columns),
-            {'ConId',
+            {'Sid',
              'Account',
              'Action',
              'OrderRef',
              'TotalQuantity',
-             'Exchange',
              'OrderType',
              'Tif'}
         )
@@ -292,24 +307,22 @@ class AllowRebalanceTestCase(unittest.TestCase):
             orders.to_dict(orient="records"),
             [
                 {
-                    'ConId': 12345,
+                    'Sid': "FI12345",
                     'Account': 'DU234',
                     'Action': 'BUY',
                     'OrderRef': 'buy-below-10',
                     # 0.3 allocation * 0.5 weight * 450K / 9.50 - (-4)
                     'TotalQuantity': 7109.0,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 },
                 {
-                    'ConId': 23456,
+                    'Sid': "FI23456",
                     'Account': 'DU234',
                     'Action': 'BUY',
                     'OrderRef': 'buy-below-10',
                     # 0 - (-7)
                     'TotalQuantity': 7.0,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 }
@@ -337,21 +350,21 @@ class AllowRebalanceTestCase(unittest.TestCase):
             def signals_to_target_weights(self, signals, prices):
                 return self.allocate_fixed_weights(signals, 0.5)
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
                         9.50
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         8.9,
                         12,
@@ -361,18 +374,21 @@ class AllowRebalanceTestCase(unittest.TestCase):
                 index=idx
             )
 
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
             master_fields = ["Timezone", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
                         "STK",
                         "USD",
                         None,
                         None
                     ],
-                    23456: [
+                    "FI23456": [
                         "America/New_York",
                         "STK",
                         "USD",
@@ -380,9 +396,11 @@ class AllowRebalanceTestCase(unittest.TestCase):
                         None
                     ],
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
         def mock_download_account_balances(f, **kwargs):
             balances = pd.DataFrame(dict(Account=["U123", "DU234", "U999"],
@@ -404,53 +422,57 @@ class AllowRebalanceTestCase(unittest.TestCase):
                     # this position won't be rebalanced
                     "Account": "U123",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 2000
                 },
                 {
                     # this position will be rebalanced
                     "Account": "U999",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 3000
                     },
                 {
                     # this position will switch sides
                     "Account": "DU234",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": -4
                 },
                 {
                     # this position will be closed
                     "Account": "DU234",
                     "OrderRef": "buy-below-10",
-                    "ConId": 23456,
+                    "Sid": "FI23456",
                     "Quantity": -7
                 },
 
             ]
             return positions
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
+        def mock_download_order_statuses(f, **kwargs):
+            pass
+
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
             with patch("moonshot.strategies.base.download_account_balances", new=mock_download_account_balances):
                 with patch("moonshot.strategies.base.download_exchange_rates", new=mock_download_exchange_rates):
                     with patch("moonshot.strategies.base.list_positions", new=mock_list_positions):
+                        with patch("moonshot.strategies.base.download_order_statuses", new=mock_download_order_statuses):
+                            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
 
-                        orders = BuyBelow10().trade(
-                            {"U123": 0.5,
-                             "DU234": 0.3,
-                             "U999": 0.5
-                             })
+                                orders = BuyBelow10().trade(
+                                    {"U123": 0.5,
+                                    "DU234": 0.3,
+                                    "U999": 0.5
+                                    })
 
         self.assertSetEqual(
             set(orders.columns),
-            {'ConId',
+            {'Sid',
              'Account',
              'Action',
              'OrderRef',
              'TotalQuantity',
-             'Exchange',
              'OrderType',
              'Tif'}
         )
@@ -458,36 +480,33 @@ class AllowRebalanceTestCase(unittest.TestCase):
             orders.to_dict(orient="records"),
             [
                 {
-                    'ConId': 12345,
+                    'Sid': "FI12345",
                     'Account': 'DU234',
                     'Action': 'BUY',
                     'OrderRef': 'buy-below-10',
                     # 0.3 allocation * 0.5 weight * 450K / 9.50 - (-4)
                     'TotalQuantity': 7109.0,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 },
                 {
-                    'ConId': 12345,
+                    'Sid': "FI12345",
                     'Account': 'U999',
                     'Action': 'BUY',
                     'OrderRef': 'buy-below-10',
                     # 0.5 allocation * 0.5 weight * 200K / 9.50 - 3000
                     'TotalQuantity': 2263,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 },
 
                 {
-                    'ConId': 23456,
+                    'Sid': "FI23456",
                     'Account': 'DU234',
                     'Action': 'BUY',
                     'OrderRef': 'buy-below-10',
                     # 0 - (-7)
                     'TotalQuantity': 7.0,
-                    'Exchange': 'SMART',
                     'OrderType': 'MKT',
                     'Tif': 'DAY'
                 }
@@ -513,21 +532,21 @@ class AllowRebalanceTestCase(unittest.TestCase):
             def signals_to_target_weights(self, signals, prices):
                 return self.allocate_fixed_weights(signals, 0.5)
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
-            dt_idx = pd.date_range(end=pd.Timestamp.today(), periods=3, normalize=True)
+            dt_idx = pd.date_range(end=pd.Timestamp.today(tz="America/New_York"), periods=3, normalize=True)
             fields = ["Close"]
             idx = pd.MultiIndex.from_product([fields, dt_idx], names=["Field", "Date"])
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
                         9.50
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         8.9,
                         12,
@@ -537,18 +556,21 @@ class AllowRebalanceTestCase(unittest.TestCase):
                 index=idx
             )
 
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
             master_fields = ["Timezone", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
                         "STK",
                         "USD",
                         None,
                         None
                     ],
-                    23456: [
+                    "FI23456": [
                         "America/New_York",
                         "STK",
                         "USD",
@@ -556,9 +578,11 @@ class AllowRebalanceTestCase(unittest.TestCase):
                         None
                     ],
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
         def mock_download_account_balances(f, **kwargs):
             balances = pd.DataFrame(dict(Account=["U123", "DU234", "U999"],
@@ -580,45 +604,50 @@ class AllowRebalanceTestCase(unittest.TestCase):
                     # this position won't be rebalanced
                     "Account": "U123",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 2000
                 },
                 {
                     # this position will be rebalanced
                     "Account": "U999",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": 3000
                     },
                 {
                     # this position will switch sides
                     "Account": "DU234",
                     "OrderRef": "buy-below-10",
-                    "ConId": 12345,
+                    "Sid": "FI12345",
                     "Quantity": -4
                 },
                 {
                     # this position will be closed
                     "Account": "DU234",
                     "OrderRef": "buy-below-10",
-                    "ConId": 23456,
+                    "Sid": "FI23456",
                     "Quantity": -7
                 },
 
             ]
             return positions
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
+        def mock_download_order_statuses(f, **kwargs):
+            pass
+
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
             with patch("moonshot.strategies.base.download_account_balances", new=mock_download_account_balances):
                 with patch("moonshot.strategies.base.download_exchange_rates", new=mock_download_exchange_rates):
                     with patch("moonshot.strategies.base.list_positions", new=mock_list_positions):
+                        with patch("moonshot.strategies.base.download_order_statuses", new=mock_download_order_statuses):
+                            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
 
-                        with self.assertRaises(MoonshotParameterError) as cm:
-                            BuyBelow10().trade(
-                                {"U123": 0.5,
-                                 "DU234": 0.3,
-                                 "U999": 0.5
-                                 })
+                                with self.assertRaises(MoonshotParameterError) as cm:
+                                    BuyBelow10().trade(
+                                        {"U123": 0.5,
+                                            "DU234": 0.3,
+                                            "U999": 0.5
+                                            })
 
         self.assertIn(
             "invalid value for ALLOW_REBALANCE: always (should be a float)", repr(cm.exception))
