@@ -48,7 +48,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 self.save_to_results("Signal", dollar_volumes)
                 return signals.astype(int)
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03", "2018-05-04"])
             fields = ["Close","Volume"]
@@ -56,7 +56,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -68,7 +68,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                         8800,
                         9900
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         9.89,
                         11,
@@ -85,31 +85,47 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
-                        "America/New_York"
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
                     ],
-                    23456: [
-                        "America/New_York"
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            with self.assertRaises(ValueError) as cm:
-                BuyBelow10().backtest()
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                with self.assertRaises(ValueError) as cm:
+                        BuyBelow10().backtest()
 
         self.assertIn("name Signal is a reserved name", repr(cm.exception))
 
-    def test_complain_if_save_custom_dataframe_with_time_in_index(self):
+    def test_complain_if_save_custom_dataframe_with_time_in_index_and_eod_result(self):
         """
-        Tests error handling when a custom dataframe is saved with Time in the index.
+        Tests error handling when a custom dataframe is saved with Time in
+        the index yet the results are EOD.
         """
 
         class ShortAbove10Intraday(Moonshot):
@@ -121,8 +137,8 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
             def prices_to_signals(self, prices):
                 morning_prices = prices.loc["Open"].xs("09:30:00", level="Time")
                 short_signals = morning_prices > 10
-                # save Nlv without taking xs
-                self.save_to_results("Nlv", prices.loc["Nlv"])
+                # save prices without taking xs
+                self.save_to_results("Open", prices.loc["Open"])
                 return -short_signals.astype(int)
 
             def signals_to_target_weights(self, signals, prices):
@@ -143,7 +159,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 gross_returns = pct_changes * positions
                 return gross_returns
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03"])
             fields = ["Close","Open"]
@@ -153,7 +169,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9.6,
                         10.45,
@@ -169,7 +185,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                         8.90,
                         11.30,
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         10.56,
                         12.01,
@@ -189,33 +205,43 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone", "Currency", "SecType"]
-            idx = pd.MultiIndex.from_product(
-                (master_fields, [dt_idx[0]], [times[0]]), names=["Field", "Date", "Time"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
+                        "ABC",
+                        "STK",
                         "USD",
-                        "STK"
+                        None,
+                        None
                     ],
-                    23456: [
+                    "FI23456": [
                         "America/New_York",
+                        "DEF",
+                        "STK",
                         "USD",
-                        "STK"
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            with self.assertRaises(MoonshotParameterError) as cm:
-                ShortAbove10Intraday().backtest(nlv={"USD":50000})
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                with self.assertRaises(MoonshotParameterError) as cm:
+                        ShortAbove10Intraday().backtest(nlv={"USD":50000})
 
         self.assertIn((
-            "custom DataFrame 'Nlv' won't concat properly with 'Time' in index, "
+            "custom DataFrame 'Open' won't concat properly with 'Time' in index, "
             "please take a cross-section first, for example: `my_dataframe.xs('15:45:00', "
             "level='Time')"), repr(cm.exception))
 
@@ -233,9 +259,8 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
             def prices_to_signals(self, prices):
                 morning_prices = prices.loc["Open"].xs("09:30:00", level="Time")
                 short_signals = morning_prices > 10
-                nlvs = prices.loc["Nlv"].xs("09:30:00", level="Time")
-                nlvs.index.name = "NotDate"
-                self.save_to_results("Nlv", nlvs)
+                morning_prices.index.name = "NotDate"
+                self.save_to_results("Price", morning_prices)
                 return -short_signals.astype(int)
 
             def signals_to_target_weights(self, signals, prices):
@@ -256,7 +281,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 gross_returns = pct_changes * positions
                 return gross_returns
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03"])
             fields = ["Close","Open"]
@@ -266,7 +291,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9.6,
                         10.45,
@@ -282,7 +307,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                         8.90,
                         11.30,
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         10.56,
                         12.01,
@@ -301,34 +326,43 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                  },
                 index=idx
             )
+            return prices
 
-            master_fields = ["Timezone", "Currency", "SecType"]
-            idx = pd.MultiIndex.from_product(
-                (master_fields, [dt_idx[0]], [times[0]]), names=["Field", "Date", "Time"])
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
+                        "ABC",
+                        "STK",
                         "USD",
-                        "STK"
+                        None,
+                        None
                     ],
-                    23456: [
+                    "FI23456": [
                         "America/New_York",
+                        "DEF",
+                        "STK",
                         "USD",
-                        "STK"
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            with self.assertRaises(MoonshotParameterError) as cm:
-                ShortAbove10Intraday().backtest(nlv={"USD":50000})
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                with self.assertRaises(MoonshotParameterError) as cm:
+                        ShortAbove10Intraday().backtest(nlv={"USD":50000})
 
         self.assertIn((
-            "custom DataFrame 'Nlv' must have index called 'Date' to concat properly, "
+            "custom DataFrame 'Price' must have index called 'Date' to concat properly, "
             "but has NotDate"), repr(cm.exception))
 
     def test_complain_if_save_custom_dataframe_not_datetime_index(self):
@@ -345,10 +379,9 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
             def prices_to_signals(self, prices):
                 morning_prices = prices.loc["Open"].xs("09:30:00", level="Time")
                 short_signals = morning_prices > 10
-                nlvs = prices.loc["Nlv"].xs("09:30:00", level="Time")
-                nlvs = nlvs.reset_index(drop=True)
-                nlvs.index.name = "Date"
-                self.save_to_results("Nlv", nlvs)
+                morning_prices = morning_prices.reset_index(drop=True)
+                morning_prices.index.name = "Date"
+                self.save_to_results("Price", morning_prices)
                 return -short_signals.astype(int)
 
             def signals_to_target_weights(self, signals, prices):
@@ -369,7 +402,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 gross_returns = pct_changes * positions
                 return gross_returns
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03"])
             fields = ["Close","Open"]
@@ -379,7 +412,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9.6,
                         10.45,
@@ -395,7 +428,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                         8.90,
                         11.30,
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         10.56,
                         12.01,
@@ -415,33 +448,43 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone", "Currency", "SecType"]
-            idx = pd.MultiIndex.from_product(
-                (master_fields, [dt_idx[0]], [times[0]]), names=["Field", "Date", "Time"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         "America/New_York",
+                        "ABC",
+                        "STK",
                         "USD",
-                        "STK"
+                        None,
+                        None
                     ],
-                    23456: [
+                    "FI23456": [
                         "America/New_York",
+                        "DEF",
+                        "STK",
                         "USD",
-                        "STK"
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            with self.assertRaises(MoonshotParameterError) as cm:
-                ShortAbove10Intraday().backtest(nlv={"USD":50000})
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                with self.assertRaises(MoonshotParameterError) as cm:
+                        ShortAbove10Intraday().backtest(nlv={"USD":50000})
 
         self.assertIn(
-            "custom DataFrame 'Nlv' must have a DatetimeIndex to concat properly",
+            "custom DataFrame 'Price' must have a DatetimeIndex to concat properly",
             repr(cm.exception))
 
     def test_save_custom_dataframe(self):
@@ -460,7 +503,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 self.save_to_results("DollarVolume", dollar_volumes)
                 return signals.astype(int)
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03", "2018-05-04"])
             fields = ["Close","Volume"]
@@ -468,7 +511,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -480,7 +523,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                         8800,
                         9900
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         9.89,
                         11,
@@ -497,24 +540,39 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
-                        "America/New_York"
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
                     ],
-                    23456: [
-                        "America/New_York"
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            results = BuyBelow10().backtest()
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10().backtest()
 
         self.assertSetEqual(
             set(results.index.get_level_values("Field")),
@@ -525,7 +583,7 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
              'Slippage',
              'NetExposure',
              'TotalHoldings',
-             'Trade',
+             'Turnover',
              'AbsWeight',
              'Weight',
              'DollarVolume'}
@@ -540,12 +598,140 @@ class SaveCustomDataFrameTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [45000.0, # 9 * 5000
+             "FI12345": [45000.0, # 9 * 5000
                      176000.0, # 11 * 16000
                      92400.0, # 10.50 * 8800
                      98901.0], # 9.99 * 9900
-             23456: [148350.0, # 9.89 * 15000
+             "FI23456": [148350.0, # 9.89 * 15000
                      154000.0, # 11 * 14000
                      244800.0, # 8.50 * 28800
                      178500.0]} # 10.50 * 17000
         )
+
+    def test_save_custom_dataframe_continuous_intraday(self):
+        """
+        Tests saving a custom dataframe to the output in a continuous intraday backtest.
+        """
+        class BuyBelow10ShortAbove10ContIntraday(Moonshot):
+            """
+            A basic test strategy that buys below 10 and shorts above 10.
+            """
+
+            def prices_to_signals(self, prices):
+                long_signals = prices.loc["Close"] <= 10
+                short_signals = prices.loc["Close"] > 10
+                self.save_to_results("TheClose", prices.loc["Close"])
+                signals = long_signals.astype(int).where(long_signals, -short_signals.astype(int))
+                return signals
+
+        def mock_get_prices(*args, **kwargs):
+
+            dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02"])
+            fields = ["Close"]
+            times = ["10:00:00", "11:00:00", "12:00:00"]
+            idx = pd.MultiIndex.from_product([fields, dt_idx, times], names=["Field", "Date", "Time"])
+
+            prices = pd.DataFrame(
+                {
+                    "FI12345": [
+                        # Close
+                        9.6,
+                        10.45,
+                        10.12,
+                        15.45,
+                        8.67,
+                        12.30,
+                    ],
+                    "FI23456": [
+                        # Close
+                        10.56,
+                        12.01,
+                        10.50,
+                        9.80,
+                        13.40,
+                        7.50,
+                    ],
+                 },
+                index=idx
+            )
+
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
+            securities = pd.DataFrame(
+                {
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
+                    ],
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
+                    ]
+                },
+                index=master_fields
+            )
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
+
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10ShortAbove10ContIntraday().backtest()
+
+        self.assertSetEqual(
+            set(results.index.get_level_values("Field")),
+            {'Commission',
+             'AbsExposure',
+             'Signal',
+             'Return',
+             'Slippage',
+             'NetExposure',
+             'TotalHoldings',
+             'Turnover',
+             'AbsWeight',
+             'Weight',
+             'TheClose'}
+        )
+
+        closes = results.loc["TheClose"].reset_index()
+        closes.loc[:, "Date"] = closes.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            closes.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+            'Time': [
+                '10:00:00',
+                '11:00:00',
+                '12:00:00',
+                '10:00:00',
+                '11:00:00',
+                '12:00:00'],
+            "FI12345": [9.6,
+                    10.45,
+                    10.12,
+                    15.45,
+                    8.67,
+                    12.30,],
+            "FI23456": [10.56,
+                    12.01,
+                    10.50,
+                    9.80,
+                    13.40,
+                    7.50,]}
+               )
