@@ -52,7 +52,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 signals = long_signals.astype(int).where(long_signals, -short_signals.astype(int))
                 return signals
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03", "2018-05-04"])
             fields = ["Close","Volume"]
@@ -60,7 +60,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -72,7 +72,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                         8800,
                         9900
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         9.89,
                         11,
@@ -89,24 +89,39 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
-                        "America/New_York"
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
                     ],
-                    23456: [
-                        "America/New_York"
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            results = BuyBelow10ShortAbove10().backtest()
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10ShortAbove10().backtest()
 
         self.assertSetEqual(
             set(results.index.get_level_values("Field")),
@@ -117,7 +132,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
              'Slippage',
              'NetExposure',
              'TotalHoldings',
-             'Trade',
+             'Turnover',
              'AbsWeight',
              'Weight'}
         )
@@ -134,11 +149,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [1.0,
+             "FI12345": [1.0,
                      -1.0,
                      -1.0,
                      1.0],
-             23456: [1.0,
+             "FI23456": [1.0,
                      -1.0,
                      1.0,
                      -1.0]}
@@ -153,11 +168,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.5,
+             "FI12345": [0.5,
                      -0.5,
                      -0.5,
                      0.5],
-             23456: [0.5,
+             "FI23456": [0.5,
                      -0.5,
                      0.5,
                      -0.5]}
@@ -172,32 +187,32 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
                      -0.5,
                      -0.5],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
                      -0.5,
                      0.5]}
         )
 
-        trades = results.loc["Trade"].reset_index()
-        trades.loc[:, "Date"] = trades.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        turnover = results.loc["Turnover"].reset_index()
+        turnover.loc[:, "Date"] = turnover.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
         self.assertDictEqual(
-            trades.to_dict(orient="list"),
+            turnover.to_dict(orient="list"),
             {'Date': [
                 '2018-05-01T00:00:00',
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      0.0],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      1.0]}
         )
 
@@ -210,11 +225,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      0.0,
                      0.0,
                      0.0],
-             23456: [0.0,
+             "FI23456": [0.0,
                      0.0,
                      0.0,
                      0.0]}
@@ -230,11 +245,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      0.0,
                      -0.0227273, # (10.50 - 11)/11 * 0.5
                      0.0242857], # (9.99 - 10.50)/10.50 * -0.5
-             23456: [0.0,
+             "FI23456": [0.0,
                      0.0,
                      -0.1136364, # (8.50 - 11)/11 * 0.5
                      -0.1176471] # (10.50 - 8.50)/8.50 * -0.5
@@ -264,7 +279,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 signals = long_signals.astype(int).where(long_signals, -short_signals.astype(int))
                 return signals
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03", "2018-05-04"])
             fields = ["Close","Volume"]
@@ -272,7 +287,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -284,7 +299,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                         8800,
                         9900
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         9.89,
                         11,
@@ -301,24 +316,39 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
-                        "America/New_York"
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
                     ],
-                    23456: [
-                        "America/New_York"
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            results = BuyBelow10ShortAbove10().backtest()
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10ShortAbove10().backtest()
 
         self.assertSetEqual(
             set(results.index.get_level_values("Field")),
@@ -329,7 +359,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
              'Slippage',
              'NetExposure',
              'TotalHoldings',
-             'Trade',
+             'Turnover',
              'AbsWeight',
              'Weight'}
         )
@@ -346,11 +376,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [1.0,
+             "FI12345": [1.0,
                      -1.0,
                      -1.0,
                      1.0],
-             23456: [1.0,
+             "FI23456": [1.0,
                      -1.0,
                      1.0,
                      -1.0]}
@@ -365,11 +395,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.5,
+             "FI12345": [0.5,
                      -0.5,
                      -0.5,
                      0.5],
-             23456: [0.5,
+             "FI23456": [0.5,
                      -0.5,
                      0.5,
                      -0.5]}
@@ -384,32 +414,32 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
                      -0.5,
                      -0.5],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
                      -0.5,
                      0.5]}
         )
 
-        trades = results.loc["Trade"].reset_index()
-        trades.loc[:, "Date"] = trades.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        turnover = results.loc["Turnover"].reset_index()
+        turnover.loc[:, "Date"] = turnover.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
         self.assertDictEqual(
-            trades.to_dict(orient="list"),
+            turnover.to_dict(orient="list"),
             {'Date': [
                 '2018-05-01T00:00:00',
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      0.0],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      1.0]}
         )
 
@@ -422,11 +452,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      0.0005,
                      0.001,
                      0.0],
-             23456: [0.0,
+             "FI23456": [0.0,
                      0.0005,
                      0.001,
                      0.001]}
@@ -442,17 +472,310 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      -0.0005,
                      -0.0237273, # (10.50 - 11)/11 * 0.5 - 0.001
                      0.0242857], # (9.99 - 10.50)/10.50 * -0.5
-             23456: [0.0,
+             "FI23456": [0.0,
                      -0.0005,
                      -0.1146364, # (8.50 - 11)/11 * 0.5 - 0.001
                      -0.1186471] # (10.50 - 8.50)/8.50 * -0.5 - 0.001
              }
         )
 
+    def test_apply_slippage_continuous_intraday(self):
+        """
+        Tests that the resulting DataFrames are correct when a single
+        slippage class is applied on a continuous intraday strategy.
+        """
+
+        class TestSlippage(FixedSlippage):
+
+            ONE_WAY_SLIPPAGE = 0.001 # 10 BPS
+
+        class BuyBelow10ShortAbove10ContIntraday(Moonshot):
+            """
+            A basic test strategy that buys below 10 and shorts above 10.
+            """
+
+            SLIPPAGE_CLASSES = TestSlippage
+
+            def prices_to_signals(self, prices):
+                long_signals = prices.loc["Close"] <= 10
+                short_signals = prices.loc["Close"] > 10
+                signals = long_signals.astype(int).where(long_signals, -short_signals.astype(int))
+                return signals
+
+        def mock_get_prices(*args, **kwargs):
+
+            dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02"])
+            fields = ["Close"]
+            times = ["10:00:00", "11:00:00", "12:00:00"]
+            idx = pd.MultiIndex.from_product([fields, dt_idx, times], names=["Field", "Date", "Time"])
+
+            prices = pd.DataFrame(
+                {
+                    "FI12345": [
+                        # Close
+                        9.6,
+                        10.45,
+                        10.12,
+                        15.45,
+                        8.67,
+                        12.30,
+                    ],
+                    "FI23456": [
+                        # Close
+                        10.56,
+                        12.01,
+                        10.50,
+                        9.80,
+                        13.40,
+                        7.50,
+                    ],
+                 },
+                index=idx
+            )
+
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
+            securities = pd.DataFrame(
+                {
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
+                    ],
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
+                    ]
+                },
+                index=master_fields
+            )
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
+
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10ShortAbove10ContIntraday().backtest()
+
+        self.assertSetEqual(
+            set(results.index.get_level_values("Field")),
+            {'Commission',
+             'AbsExposure',
+             'Signal',
+             'Return',
+             'Slippage',
+             'NetExposure',
+             'TotalHoldings',
+             'Turnover',
+             'AbsWeight',
+             'Weight'}
+        )
+
+        results = results.round(7)
+        results = results.where(results.notnull(), "nan")
+
+        signals = results.loc["Signal"].reset_index()
+        signals.loc[:, "Date"] = signals.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            signals.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+             'Time': ['10:00:00',
+                      '11:00:00',
+                      '12:00:00',
+                      '10:00:00',
+                      '11:00:00',
+                      '12:00:00'],
+             "FI12345": [1.0,
+                     -1.0,
+                     -1.0,
+                     -1.0,
+                     1.0,
+                     -1.0],
+             "FI23456": [-1.0,
+                     -1.0,
+                     -1.0,
+                     1.0,
+                     -1.0,
+                     1.0]}
+        )
+
+        weights = results.loc["Weight"].reset_index()
+        weights.loc[:, "Date"] = weights.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            weights.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+             'Time': ['10:00:00',
+                      '11:00:00',
+                      '12:00:00',
+                      '10:00:00',
+                      '11:00:00',
+                      '12:00:00'],
+             "FI12345": [0.5,
+                     -0.5,
+                     -0.5,
+                     -0.5,
+                     0.5,
+                     -0.5],
+             "FI23456": [-0.5,
+                     -0.5,
+                     -0.5,
+                     0.5,
+                     -0.5,
+                     0.5]}
+        )
+
+        net_positions = results.loc["NetExposure"].reset_index()
+        net_positions.loc[:, "Date"] = net_positions.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            net_positions.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+             'Time': ['10:00:00',
+                      '11:00:00',
+                      '12:00:00',
+                      '10:00:00',
+                      '11:00:00',
+                      '12:00:00'],
+             "FI12345": ['nan',
+                     0.5,
+                     -0.5,
+                     -0.5,
+                     -0.5,
+                     0.5],
+             "FI23456": ['nan',
+                     -0.5,
+                     -0.5,
+                     -0.5,
+                     0.5,
+                     -0.5]}
+        )
+
+        turnover = results.loc["Turnover"].reset_index()
+        turnover.loc[:, "Date"] = turnover.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            turnover.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+             'Time': ['10:00:00',
+                      '11:00:00',
+                      '12:00:00',
+                      '10:00:00',
+                      '11:00:00',
+                      '12:00:00'],
+             "FI12345": ['nan',
+                     0.5,
+                     1.0,
+                     0.0,
+                     0.0,
+                     1.0],
+             "FI23456": ['nan',
+                     0.5,
+                     0.0,
+                     0.0,
+                     1.0,
+                     1.0]}
+        )
+
+        slippage = results.loc["Slippage"].reset_index()
+        slippage.loc[:, "Date"] = slippage.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            slippage.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+             'Time': ['10:00:00',
+                      '11:00:00',
+                      '12:00:00',
+                      '10:00:00',
+                      '11:00:00',
+                      '12:00:00'],
+             "FI12345": [0.0,
+                     0.0005,
+                     0.001,
+                     0.0,
+                     0.0,
+                     0.001],
+             "FI23456": [0.0,
+                     0.0005,
+                     0.0,
+                     0.0,
+                     0.001,
+                     0.001]}
+        )
+
+        returns = results.loc["Return"].reset_index()
+        returns.loc[:, "Date"] = returns.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        self.assertDictEqual(
+            returns.to_dict(orient="list"),
+            {'Date': [
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-01T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00',
+                '2018-05-02T00:00:00'],
+             'Time': ['10:00:00',
+                      '11:00:00',
+                      '12:00:00',
+                      '10:00:00',
+                      '11:00:00',
+                      '12:00:00'],
+             "FI12345": [0.0,
+                     -0.0005,
+                     -0.0167895, # (10.12-10.45)/10.45 * 0.5 - 0.001
+                     -0.2633399, # (15.45-10.12)/10.12 * -0.5
+                     0.2194175,  # (8.67-15.45)/15.45 * -0.5
+                     -0.2103426  # (12.30-8.67)/8.67 * -0.5 - 0.001
+                     ],
+             "FI23456": [0.0,
+                     -0.0005,
+                     0.0628643, # (10.50-12.01)/12.01 * -0.5
+                     0.0333333, # (9.80-10.50)/10.50 * -0.5
+                     -0.1846735, # (13.40-9.80)/9.80 * -0.5 - 0.001
+                     -0.2211493 # (7.50-13.40)/13.40 * 0.5 - 0.001
+                     ]}
+        )
+
     def test_apply_SLIPPAGE_BPS(self):
         """
         Tests that the resulting DataFrames are correct when SLIPPAGE_BPS is
@@ -472,7 +795,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 signals = long_signals.astype(int).where(long_signals, -short_signals.astype(int))
                 return signals
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03", "2018-05-04"])
             fields = ["Close","Volume"]
@@ -480,7 +803,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -492,7 +815,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                         8800,
                         9900
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         9.89,
                         11,
@@ -509,24 +832,39 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
-                        "America/New_York"
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
                     ],
-                    23456: [
-                        "America/New_York"
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            results = BuyBelow10ShortAbove10().backtest()
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10ShortAbove10().backtest()
 
         self.assertSetEqual(
             set(results.index.get_level_values("Field")),
@@ -537,7 +875,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
              'Slippage',
              'NetExposure',
              'TotalHoldings',
-             'Trade',
+             'Turnover',
              'AbsWeight',
              'Weight'}
         )
@@ -554,11 +892,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [1.0,
+             "FI12345": [1.0,
                      -1.0,
                      -1.0,
                      1.0],
-             23456: [1.0,
+             "FI23456": [1.0,
                      -1.0,
                      1.0,
                      -1.0]}
@@ -573,11 +911,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.5,
+             "FI12345": [0.5,
                      -0.5,
                      -0.5,
                      0.5],
-             23456: [0.5,
+             "FI23456": [0.5,
                      -0.5,
                      0.5,
                      -0.5]}
@@ -592,32 +930,32 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
                      -0.5,
                      -0.5],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
                      -0.5,
                      0.5]}
         )
 
-        trades = results.loc["Trade"].reset_index()
-        trades.loc[:, "Date"] = trades.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        turnover = results.loc["Turnover"].reset_index()
+        turnover.loc[:, "Date"] = turnover.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
         self.assertDictEqual(
-            trades.to_dict(orient="list"),
+            turnover.to_dict(orient="list"),
             {'Date': [
                 '2018-05-01T00:00:00',
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      0.0],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      1.0]}
         )
 
@@ -630,11 +968,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      0.001,
                      0.002,
                      0.0],
-             23456: [0.0,
+             "FI23456": [0.0,
                      0.001,
                      0.002,
                      0.002]}
@@ -650,11 +988,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      -0.001,
                      -0.0247273, # (10.50 - 11)/11 * 0.5 - 0.002
                      0.0242857], # (9.99 - 10.50)/10.50 * -0.5
-             23456: [0.0,
+             "FI23456": [0.0,
                      -0.001,
                      -0.1156364, # (8.50 - 11)/11 * 0.5 - 0.002
                      -0.1196471] # (10.50 - 8.50)/8.50 * -0.5 - 0.002
@@ -689,7 +1027,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 signals = long_signals.astype(int).where(long_signals, -short_signals.astype(int))
                 return signals
 
-        def mock_get_historical_prices(*args, **kwargs):
+        def mock_get_prices(*args, **kwargs):
 
             dt_idx = pd.DatetimeIndex(["2018-05-01","2018-05-02","2018-05-03", "2018-05-04"])
             fields = ["Close","Volume"]
@@ -697,7 +1035,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
 
             prices = pd.DataFrame(
                 {
-                    12345: [
+                    "FI12345": [
                         # Close
                         9,
                         11,
@@ -709,7 +1047,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                         8800,
                         9900
                     ],
-                    23456: [
+                    "FI23456": [
                         # Close
                         9.89,
                         11,
@@ -726,24 +1064,39 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 index=idx
             )
 
-            master_fields = ["Timezone"]
-            idx = pd.MultiIndex.from_product((master_fields, [dt_idx[0]]), names=["Field", "Date"])
+            return prices
+
+        def mock_download_master_file(f, *args, **kwargs):
+
+            master_fields = ["Timezone", "Symbol", "SecType", "Currency", "PriceMagnifier", "Multiplier"]
             securities = pd.DataFrame(
                 {
-                    12345: [
-                        "America/New_York"
+                    "FI12345": [
+                        "America/New_York",
+                        "ABC",
+                        "STK",
+                        "USD",
+                        None,
+                        None
                     ],
-                    23456: [
-                        "America/New_York"
+                    "FI23456": [
+                        "America/New_York",
+                        "DEF",
+                        "STK",
+                        "USD",
+                        None,
+                        None,
                     ]
                 },
-                index=idx
+                index=master_fields
             )
-            return pd.concat((prices, securities))
+            securities.columns.name = "Sid"
+            securities.T.to_csv(f, index=True, header=True)
+            f.seek(0)
 
-        with patch("moonshot.strategies.base.get_historical_prices", new=mock_get_historical_prices):
-
-            results = BuyBelow10ShortAbove10().backtest()
+        with patch("moonshot.strategies.base.get_prices", new=mock_get_prices):
+            with patch("moonshot.strategies.base.download_master_file", new=mock_download_master_file):
+                results = BuyBelow10ShortAbove10().backtest()
 
         self.assertSetEqual(
             set(results.index.get_level_values("Field")),
@@ -754,7 +1107,7 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
              'Slippage',
              'NetExposure',
              'TotalHoldings',
-             'Trade',
+             'Turnover',
              'AbsWeight',
              'Weight'}
         )
@@ -771,11 +1124,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [1.0,
+             "FI12345": [1.0,
                      -1.0,
                      -1.0,
                      1.0],
-             23456: [1.0,
+             "FI23456": [1.0,
                      -1.0,
                      1.0,
                      -1.0]}
@@ -790,11 +1143,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.5,
+             "FI12345": [0.5,
                      -0.5,
                      -0.5,
                      0.5],
-             23456: [0.5,
+             "FI23456": [0.5,
                      -0.5,
                      0.5,
                      -0.5]}
@@ -809,32 +1162,32 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
                      -0.5,
                      -0.5],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
                      -0.5,
                      0.5]}
         )
 
-        trades = results.loc["Trade"].reset_index()
-        trades.loc[:, "Date"] = trades.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
+        turnover = results.loc["Turnover"].reset_index()
+        turnover.loc[:, "Date"] = turnover.Date.dt.strftime("%Y-%m-%dT%H:%M:%S%z")
         self.assertDictEqual(
-            trades.to_dict(orient="list"),
+            turnover.to_dict(orient="list"),
             {'Date': [
                 '2018-05-01T00:00:00',
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: ["nan",
+             "FI12345": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      0.0],
-             23456: ["nan",
+             "FI23456": ["nan",
                      0.5,
-                     -1.0,
+                     1.0,
                      1.0]}
         )
 
@@ -847,11 +1200,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      0.005,
                      0.01,
                      0.0],
-             23456: [0.0,
+             "FI23456": [0.0,
                      0.005,
                      0.01,
                      0.01]}
@@ -867,11 +1220,11 @@ class MoonshotSlippgeTestCase(unittest.TestCase):
                 '2018-05-02T00:00:00',
                 '2018-05-03T00:00:00',
                 '2018-05-04T00:00:00'],
-             12345: [0.0,
+             "FI12345": [0.0,
                      -0.005,
                      -0.0327273, # (10.50 - 11)/11 * 0.5 - 0.01
                      0.0242857], # (9.99 - 10.50)/10.50 * -0.5
-             23456: [0.0,
+             "FI23456": [0.0,
                      -0.005,
                      -0.1236364, # (8.50 - 11)/11 * 0.5 - 0.001
                      -0.1276471] # (10.50 - 8.50)/8.50 * -0.5 - 0.01
